==> monaco-vscode-task-service-override-2.2.0.tgz: package/vscode/src/vs/workbench/contrib/tasks/browser/taskTerminalStatus.js <==
import { __decorate, __param } from '../../../../../../../external/tslib/tslib.es6.js';
import { localizeWithPath } from 'vscode/vscode/vs/nls';
import { Codicon } from 'vscode/vscode/vs/base/common/codicons';
import { Disposable, toDisposable, MutableDisposable } from 'vscode/vscode/vs/base/common/lifecycle';
import Severity from 'vscode/vscode/vs/base/common/severity';
import { StartStopProblemCollector } from '../common/problemCollectors.js';
import { ITaskService } from 'vscode/vscode/vs/workbench/contrib/tasks/common/taskService';
import { MarkerSeverity } from 'vscode/vscode/vs/platform/markers/common/markers';
import { spinningLoading } from 'vscode/vscode/vs/platform/theme/common/iconRegistry';
import { AudioCue, IAudioCueService } from 'vscode/vscode/vs/platform/audioCues/browser/audioCueService';

const TASK_TERMINAL_STATUS_ID = 'task_terminal_status';
const ACTIVE_TASK_STATUS = { id: TASK_TERMINAL_STATUS_ID, icon: spinningLoading, severity: Severity.Info, tooltip: ( localizeWithPath(
    'vs/workbench/contrib/tasks/browser/taskTerminalStatus',
    'taskTerminalStatus.active',
    "Task is running"
)) };
const SUCCEEDED_TASK_STATUS = { id: TASK_TERMINAL_STATUS_ID, icon: Codicon.check, severity: Severity.Info, tooltip: ( localizeWithPath(
    'vs/workbench/contrib/tasks/browser/taskTerminalStatus',
    'taskTerminalStatus.succeeded',
    "Task succeeded"
)) };
const SUCCEEDED_INACTIVE_TASK_STATUS = { id: TASK_TERMINAL_STATUS_ID, icon: Codicon.check, severity: Severity.Info, tooltip: ( localizeWithPath(
    'vs/workbench/contrib/tasks/browser/taskTerminalStatus',
    'taskTerminalStatus.succeededInactive',
    "Task succeeded and waiting..."
)) };
const FAILED_TASK_STATUS = { id: TASK_TERMINAL_STATUS_ID, icon: Codicon.error, severity: Severity.Error, tooltip: ( localizeWithPath(
    'vs/workbench/contrib/tasks/browser/taskTerminalStatus',
    'taskTerminalStatus.errors',
    "Task has errors"
)) };
const FAILED_INACTIVE_TASK_STATUS = { id: TASK_TERMINAL_STATUS_ID, icon: Codicon.error, severity: Severity.Error, tooltip: ( localizeWithPath(
    'vs/workbench/contrib/tasks/browser/taskTerminalStatus',
    'taskTerminalStatus.errorsInactive',
    "Task has errors and is waiting..."
)) };
const WARNING_TASK_STATUS = { id: TASK_TERMINAL_STATUS_ID, icon: Codicon.warning, severity: Severity.Warning, tooltip: ( localizeWithPath(
    'vs/workbench/contrib/tasks/browser/taskTerminalStatus',
    'taskTerminalStatus.warnings',
    "Task has warnings"
)) };
const WARNING_INACTIVE_TASK_STATUS = { id: TASK_TERMINAL_STATUS_ID, icon: Codicon.warning, severity: Severity.Warning, tooltip: ( localizeWithPath(
    'vs/workbench/contrib/tasks/browser/taskTerminalStatus',
    'taskTerminalStatus.warningsInactive',
    "Task has warnings and is waiting..."
)) };
const INFO_TASK_STATUS = { id: TASK_TERMINAL_STATUS_ID, icon: Codicon.info, severity: Severity.Info, tooltip: ( localizeWithPath(
    'vs/workbench/contrib/tasks/browser/taskTerminalStatus',
    'taskTerminalStatus.infos',
    "Task has infos"
)) };
const INFO_INACTIVE_TASK_STATUS = { id: TASK_TERMINAL_STATUS_ID, icon: Codicon.info, severity: Severity.Info, tooltip: ( localizeWithPath(
    'vs/workbench/contrib/tasks/browser/taskTerminalStatus',
    'taskTerminalStatus.infosInactive',
    "Task has infos and is waiting..."
)) };
let TaskTerminalStatus = class TaskTerminalStatus extends Disposable {
    constructor(taskService, _audioCueService) {
        super();
        this._audioCueService = _audioCueService;
        this.terminalMap = ( new Map());
        this._register(taskService.onDidStateChange((event) => {
            switch (event.kind) {
                case "processStarted" :
                case "active" :
                    this.eventActive(event);
                    break;
                case "inactive" :
                    this.eventInactive(event);
                    break;
                case "processEnded" :
                    this.eventEnd(event);
                    break;
            }
        }));
        this._register(toDisposable(() => {
            for (const terminalData of ( this.terminalMap.values())) {
                terminalData.disposeListener?.dispose();
            }
            this.terminalMap.clear();
        }));
    }
    addTerminal(task, terminal, problemMatcher) {
        const status = { id: TASK_TERMINAL_STATUS_ID, severity: Severity.Info };
        terminal.statusList.add(status);
        this._register(problemMatcher.onDidFindFirstMatch(() => {
            this._marker = terminal.registerMarker();
            if (this._marker) {
                this._register(this._marker);
            }
        }));
        this._register(problemMatcher.onDidFindErrors(() => {
            if (this._marker) {
                terminal.addBufferMarker({ marker: this._marker, hoverMessage: ( localizeWithPath(
                    'vs/workbench/contrib/tasks/browser/taskTerminalStatus',
                    'task.watchFirstError',
                    "Beginning of detected errors for this run"
                )), disableCommandStorage: true });
            }
        }));
        this._register(problemMatcher.onDidRequestInvalidateLastMarker(() => {
            this._marker?.dispose();
            this._marker = undefined;
        }));
        this.terminalMap.set(terminal.instanceId, { terminal, task, status, problemMatcher, taskRunEnded: false });
    }
    terminalFromEvent(event) {
        if (!('terminalId' in event) || !event.terminalId) {
            return undefined;
        }
        return this.terminalMap.get(event.terminalId);
    }
    eventEnd(event) {
        const terminalData = this.terminalFromEvent(event);
        if (!terminalData) {
            return;
        }
        terminalData.taskRunEnded = true;
        terminalData.terminal.statusList.remove(terminalData.status);
        if ((event.exitCode === 0) && (terminalData.problemMatcher.numberOfMatches === 0)) {
            this._audioCueService.playAudioCue(AudioCue.taskCompleted);
            if (terminalData.task.configurationProperties.isBackground) {
                for (const status of terminalData.terminal.statusList.statuses) {
                    terminalData.terminal.statusList.remove(status);
                }
            }
            else {
                terminalData.terminal.statusList.add(SUCCEEDED_TASK_STATUS);
            }
        }
        else if (event.exitCode || terminalData.problemMatcher.maxMarkerSeverity === MarkerSeverity.Error) {
            this._audioCueService.playAudioCue(AudioCue.taskFailed);
            terminalData.terminal.statusList.add(FAILED_TASK_STATUS);
        }
        else if (terminalData.problemMatcher.maxMarkerSeverity === MarkerSeverity.Warning) {
            terminalData.terminal.statusList.add(WARNING_TASK_STATUS);
        }
        else if (terminalData.problemMatcher.maxMarkerSeverity === MarkerSeverity.Info) {
            terminalData.terminal.statusList.add(INFO_TASK_STATUS);
        }
    }
    eventInactive(event) {
        const terminalData = this.terminalFromEvent(event);
        if (!terminalData || !terminalData.problemMatcher || terminalData.taskRunEnded) {
            return;
        }
        terminalData.terminal.statusList.remove(terminalData.status);
        if (terminalData.problemMatcher.numberOfMatches === 0) {
            this._audioCueService.playAudioCue(AudioCue.taskCompleted);
            terminalData.terminal.statusList.add(SUCCEEDED_INACTIVE_TASK_STATUS);
        }
        else if (terminalData.problemMatcher.maxMarkerSeverity === MarkerSeverity.Error) {
            this._audioCueService.playAudioCue(AudioCue.taskFailed);
            terminalData.terminal.statusList.add(FAILED_INACTIVE_TASK_STATUS);
        }
        else if (terminalData.problemMatcher.maxMarkerSeverity === MarkerSeverity.Warning) {
            terminalData.terminal.statusList.add(WARNING_INACTIVE_TASK_STATUS);
        }
        else if (terminalData.problemMatcher.maxMarkerSeverity === MarkerSeverity.Info) {
            terminalData.terminal.statusList.add(INFO_INACTIVE_TASK_STATUS);
        }
    }
    eventActive(event) {
        const terminalData = this.terminalFromEvent(event);
        if (!terminalData) {
            return;
        }
        if (!terminalData.disposeListener) {
            terminalData.disposeListener = this._register(( new MutableDisposable()));
            terminalData.disposeListener.value = terminalData.terminal.onDisposed(() => {
                if (!event.terminalId) {
                    return;
                }
                this.terminalMap.delete(event.terminalId);
                terminalData.disposeListener?.dispose();
            });
        }
        terminalData.taskRunEnded = false;
        terminalData.terminal.statusList.remove(terminalData.status);
        if ((terminalData.problemMatcher instanceof StartStopProblemCollector) || (terminalData.problemMatcher?.problemMatchers.length > 0) || event.runType === "singleRun" ) {
            terminalData.terminal.statusList.add(ACTIVE_TASK_STATUS);
        }
    }
};
TaskTerminalStatus = ( __decorate([
    ( __param(0, ITaskService)),
    ( __param(1, IAudioCueService))
], TaskTerminalStatus));

export { ACTIVE_TASK_STATUS, FAILED_TASK_STATUS, SUCCEEDED_TASK_STATUS, TaskTerminalStatus };

==> monaco-vscode-task-service-override-3.1.0.tgz: package/vscode/src/vs/workbench/contrib/tasks/browser/taskTerminalStatus.js <==
import { __decorate, __param } from '../../../../../../../external/tslib/tslib.es6.js';
import { localizeWithPath } from 'vscode/vscode/vs/nls';
import { Codicon } from 'vscode/vscode/vs/base/common/codicons';
import { Disposable, toDisposable, MutableDisposable } from 'vscode/vscode/vs/base/common/lifecycle';
import Severity from 'vscode/vscode/vs/base/common/severity';
import { StartStopProblemCollector } from '../common/problemCollectors.js';
import { ITaskService } from 'vscode/vscode/vs/workbench/contrib/tasks/common/taskService';
import { MarkerSeverity } from 'vscode/vscode/vs/platform/markers/common/markers';
import { spinningLoading } from 'vscode/vscode/vs/platform/theme/common/iconRegistry';
import { AccessibilitySignal, IAccessibilitySignalService } from 'vscode/vscode/vs/platform/accessibilitySignal/browser/accessibilitySignalService';

const TASK_TERMINAL_STATUS_ID = 'task_terminal_status';
const ACTIVE_TASK_STATUS = { id: TASK_TERMINAL_STATUS_ID, icon: spinningLoading, severity: Severity.Info, tooltip: ( localizeWithPath(
    'vs/workbench/contrib/tasks/browser/taskTerminalStatus',
    'taskTerminalStatus.active',
    "Task is running"
)) };
const SUCCEEDED_TASK_STATUS = { id: TASK_TERMINAL_STATUS_ID, icon: Codicon.check, severity: Severity.Info, tooltip: ( localizeWithPath(
    'vs/workbench/contrib/tasks/browser/taskTerminalStatus',
    'taskTerminalStatus.succeeded',
    "Task succeeded"
)) };
const SUCCEEDED_INACTIVE_TASK_STATUS = { id: TASK_TERMINAL_STATUS_ID, icon: Codicon.check, severity: Severity.Info, tooltip: ( localizeWithPath(
    'vs/workbench/contrib/tasks/browser/taskTerminalStatus',
    'taskTerminalStatus.succeededInactive',
    "Task succeeded and waiting..."
)) };
const FAILED_TASK_STATUS = { id: TASK_TERMINAL_STATUS_ID, icon: Codicon.error, severity: Severity.Error, tooltip: ( localizeWithPath(
    'vs/workbench/contrib/tasks/browser/taskTerminalStatus',
    'taskTerminalStatus.errors',
    "Task has errors"
)) };
const FAILED_INACTIVE_TASK_STATUS = { id: TASK_TERMINAL_STATUS_ID, icon: Codicon.error, severity: Severity.Error, tooltip: ( localizeWithPath(
    'vs/workbench/contrib/tasks/browser/taskTerminalStatus',
    'taskTerminalStatus.errorsInactive',
    "Task has errors and is waiting..."
)) };
const WARNING_TASK_STATUS = { id: TASK_TERMINAL_STATUS_ID, icon: Codicon.warning, severity: Severity.Warning, tooltip: ( localizeWithPath(
    'vs/workbench/contrib/tasks/browser/taskTerminalStatus',
    'taskTerminalStatus.warnings',
    "Task has warnings"
)) };
const WARNING_INACTIVE_TASK_STATUS = { id: TASK_TERMINAL_STATUS_ID, icon: Codicon.warning, severity: Severity.Warning, tooltip: ( localizeWithPath(
    'vs/workbench/contrib/tasks/browser/taskTerminalStatus',
    'taskTerminalStatus.warningsInactive',
    "Task has warnings and is waiting..."
)) };
const INFO_TASK_STATUS = { id: TASK_TERMINAL_STATUS_ID, icon: Codicon.info, severity: Severity.Info, tooltip: ( localizeWithPath(
    'vs/workbench/contrib/tasks/browser/taskTerminalStatus',
    'taskTerminalStatus.infos',
    "Task has infos"
)) };
const INFO_INACTIVE_TASK_STATUS = { id: TASK_TERMINAL_STATUS_ID, icon: Codicon.info, severity: Severity.Info, tooltip: ( localizeWithPath(
    'vs/workbench/contrib/tasks/browser/taskTerminalStatus',
    'taskTerminalStatus.infosInactive',
    "Task has infos and is waiting..."
)) };
let TaskTerminalStatus = class TaskTerminalStatus extends Disposable {
    constructor(taskService, _accessibilitySignalService) {
        super();
        this._accessibilitySignalService = _accessibilitySignalService;
        this.terminalMap = ( new Map());
        this._register(taskService.onDidStateChange((event) => {
            switch (event.kind) {
                case "processStarted" :
                case "active" :
                    this.eventActive(event);
                    break;
                case "inactive" :
                    this.eventInactive(event);
                    break;
                case "processEnded" :
                    this.eventEnd(event);
                    break;
            }
        }));
        this._register(toDisposable(() => {
            for (const terminalData of ( this.terminalMap.values())) {
                terminalData.disposeListener?.dispose();
            }
            this.terminalMap.clear();
        }));
    }
    addTerminal(task, terminal, problemMatcher) {
        const status = { id: TASK_TERMINAL_STATUS_ID, severity: Severity.Info };
        terminal.statusList.add(status);
        this._register(problemMatcher.onDidFindFirstMatch(() => {
            this._marker = terminal.registerMarker();
            if (this._marker) {
                this._register(this._marker);
            }
        }));
        this._register(problemMatcher.onDidFindErrors(() => {
            if (this._marker) {
                terminal.addBufferMarker({ marker: this._marker, hoverMessage: ( localizeWithPath(
                    'vs/workbench/contrib/tasks/browser/taskTerminalStatus',
                    'task.watchFirstError',
                    "Beginning of detected errors for this run"
                )), disableCommandStorage: true });
            }
        }));
        this._register(problemMatcher.onDidRequestInvalidateLastMarker(() => {
            this._marker?.dispose();
            this._marker = undefined;
        }));
        this.terminalMap.set(terminal.instanceId, { terminal, task, status, problemMatcher, taskRunEnded: false });
    }
    terminalFromEvent(event) {
        if (!('terminalId' in event) || !event.terminalId) {
            return undefined;
        }
        return this.terminalMap.get(event.terminalId);
    }
    eventEnd(event) {
        const terminalData = this.terminalFromEvent(event);
        if (!terminalData) {
            return;
        }
        terminalData.taskRunEnded = true;
        terminalData.terminal.statusList.remove(terminalData.status);
        if ((event.exitCode === 0) && (terminalData.problemMatcher.numberOfMatches === 0)) {
            this._accessibilitySignalService.playSignal(AccessibilitySignal.taskCompleted);
            if (terminalData.task.configurationProperties.isBackground) {
                for (const status of terminalData.terminal.statusList.statuses) {
                    terminalData.terminal.statusList.remove(status);
                }
            }
            else {
                terminalData.terminal.statusList.add(SUCCEEDED_TASK_STATUS);
            }
        }
        else if (event.exitCode || terminalData.problemMatcher.maxMarkerSeverity === MarkerSeverity.Error) {
            this._accessibilitySignalService.playSignal(AccessibilitySignal.taskFailed);
            terminalData.terminal.statusList.add(FAILED_TASK_STATUS);
        }
        else if (terminalData.problemMatcher.maxMarkerSeverity === MarkerSeverity.Warning) {
            terminalData.terminal.statusList.add(WARNING_TASK_STATUS);
        }
        else if (terminalData.problemMatcher.maxMarkerSeverity === MarkerSeverity.Info) {
            terminalData.terminal.statusList.add(INFO_TASK_STATUS);
        }
    }
    eventInactive(event) {
        const terminalData = this.terminalFromEvent(event);
        if (!terminalData || !terminalData.problemMatcher || terminalData.taskRunEnded) {
            return;
        }
        terminalData.terminal.statusList.remove(terminalData.status);
        if (terminalData.problemMatcher.numberOfMatches === 0) {
            this._accessibilitySignalService.playSignal(AccessibilitySignal.taskCompleted);
            terminalData.terminal.statusList.add(SUCCEEDED_INACTIVE_TASK_STATUS);
        }
        else if (terminalData.problemMatcher.maxMarkerSeverity === MarkerSeverity.Error) {
            this._accessibilitySignalService.playSignal(AccessibilitySignal.taskFailed);
            terminalData.terminal.statusList.add(FAILED_INACTIVE_TASK_STATUS);
        }
        else if (terminalData.problemMatcher.maxMarkerSeverity === MarkerSeverity.Warning) {
            terminalData.terminal.statusList.add(WARNING_INACTIVE_TASK_STATUS);
        }
        else if (terminalData.problemMatcher.maxMarkerSeverity === MarkerSeverity.Info) {
            terminalData.terminal.statusList.add(INFO_INACTIVE_TASK_STATUS);
        }
    }
    eventActive(event) {
        const terminalData = this.terminalFromEvent(event);
        if (!terminalData) {
            return;
        }
        if (!terminalData.disposeListener) {
            terminalData.disposeListener = this._register(( new MutableDisposable()));
            terminalData.disposeListener.value = terminalData.terminal.onDisposed(() => {
                if (!event.terminalId) {
                    return;
                }
                this.terminalMap.delete(event.terminalId);
                terminalData.disposeListener?.dispose();
            });
        }
        terminalData.taskRunEnded = false;
        terminalData.terminal.statusList.remove(terminalData.status);
        if ((terminalData.problemMatcher instanceof StartStopProblemCollector) || (terminalData.problemMatcher?.problemMatchers.length > 0) || event.runType === "singleRun" ) {
            terminalData.terminal.statusList.add(ACTIVE_TASK_STATUS);
        }
    }
};
TaskTerminalStatus = ( __decorate([
    ( __param(0, ITaskService)),
    ( __param(1, IAccessibilitySignalService))
], TaskTerminalStatus));

export { ACTIVE_TASK_STATUS, FAILED_TASK_STATUS, SUCCEEDED_TASK_STATUS, TaskTerminalStatus };
